Class: CybridApiId::ApiClient
- Inherits:
-
Object
- Object
- CybridApiId::ApiClient
- Defined in:
- lib/cybrid_api_id_ruby/api_client.rb
Instance Attribute Summary collapse
-
#config ⇒ Object
The Configuration object holding settings to be used in the API client.
-
#default_headers ⇒ Hash
Defines the headers to be used in HTTP requests of all API calls by default.
Class Method Summary collapse
Instance Method Summary collapse
-
#build_collection_param(param, collection_format) ⇒ Object
Build parameter value according to the given collection format.
-
#build_request(http_method, path, opts = {}) ⇒ HTTPX::Request
Builds the HTTP request.
-
#build_request_body(header_params, form_params, body) ⇒ Hash{Symbol => Object}
Builds the HTTP request body.
- #build_request_url(path, opts = {}) ⇒ Object
-
#call_api(http_method, path, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Call an API with given options.
-
#convert_to_type(data, return_type) ⇒ Mixed
Convert data to the given return type.
-
#deserialize(response, return_type) ⇒ Object
Deserialize the response to the given return type.
- #deserialize_file(response) ⇒ Object
-
#initialize(config = Configuration.default) ⇒ ApiClient
constructor
Initializes the ApiClient.
-
#json_mime?(mime) ⇒ Boolean
Check if the given MIME is a JSON MIME.
-
#object_to_hash(obj) ⇒ String
Convert object(non-array) to hash.
-
#object_to_http_body(model) ⇒ String
Convert object (array, hash, object, etc) to JSON string.
-
#sanitize_filename(filename) ⇒ String
Sanitize filename by removing path.
-
#select_header_accept(accepts) ⇒ String
Return Accept header based on an array of accepts provided.
-
#select_header_content_type(content_types) ⇒ String
Return Content-Type header based on an array of content types provided.
- #session ⇒ Object
-
#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object
Update header and query params based on authentication settings.
-
#user_agent=(user_agent) ⇒ Object
Sets user agent in HTTP header.
Constructor Details
#initialize(config = Configuration.default) ⇒ ApiClient
Initializes the ApiClient
34 35 36 37 38 39 40 41 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 34 def initialize(config = Configuration.default) @config = config @user_agent = "OpenAPI-Generator/#{VERSION}/ruby" @default_headers = { 'Content-Type' => 'application/json', 'User-Agent' => @user_agent } end |
Instance Attribute Details
#config ⇒ Object
The Configuration object holding settings to be used in the API client.
25 26 27 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 25 def config @config end |
#default_headers ⇒ Hash
Defines the headers to be used in HTTP requests of all API calls by default.
30 31 32 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 30 def default_headers @default_headers end |
Class Method Details
Instance Method Details
#build_collection_param(param, collection_format) ⇒ Object
Build parameter value according to the given collection format.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 352 def build_collection_param(param, collection_format) case collection_format when :csv param.join(',') when :ssv param.join(' ') when :tsv param.join("\t") when :pipes param.join('|') when :multi # return the array directly as typhoeus will handle it as expected param else fail "unknown collection format: #{collection_format.inspect}" end end |
#build_request(http_method, path, opts = {}) ⇒ HTTPX::Request
Builds the HTTP request
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 91 def build_request(http_method, path, opts = {}) url = build_request_url(path, opts) header_params = @default_headers.merge(opts[:header_params] || {}) query_params = opts[:query_params] || {} form_params = opts[:form_params] || {} update_params_for_auth! header_params, query_params, opts[:auth_names] if %w[POST PATCH PUT DELETE].include?(http_method) body_params = build_request_body(header_params, form_params, opts[:body]) if config.debugging config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n" end end req_opts = { :headers => HTTPX::Headers.new(header_params) } req_opts.merge!(body_params) if body_params req_opts[:params] = query_params if query_params && !query_params.empty? session.request(http_method, url, **req_opts) end |
#build_request_body(header_params, form_params, body) ⇒ Hash{Symbol => Object}
Builds the HTTP request body
120 121 122 123 124 125 126 127 128 129 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 120 def build_request_body(header_params, form_params, body) # http form if header_params['Content-Type'] == 'application/x-www-form-urlencoded' || header_params['Content-Type'] == 'multipart/form-data' header_params.delete('Content-Type') # httpx takes care of this { form: form_params } elsif body body.is_a?(String) ? { body: body } : { json: body } end end |
#build_request_url(path, opts = {}) ⇒ Object
273 274 275 276 277 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 273 def build_request_url(path, opts = {}) # Add leading and trailing slashes to path path = "/#{path}".gsub(/\/+/, '/') @config.base_url(opts[:operation]) + path end |
#call_api(http_method, path, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Call an API with given options.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 51 def call_api(http_method, path, opts = {}) begin response = build_request(http_method.to_s, path, opts) if config.debugging config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n" end response.raise_for_status rescue HTTPX::HTTPError fail ApiError.new(code: response.status, response_headers: response.headers.to_h, response_body: response.body.to_s), Net::HTTP::STATUS_CODES.fetch(response.status, "HTTP Error (#{response.status})") rescue HTTPX::TimeoutError fail ApiError.new('Connection timed out') rescue HTTPX::ConnectionError, HTTPX::ResolveError fail ApiError.new('Connection failed') end if opts[:return_type] == 'File' data = deserialize_file(response) elsif opts[:return_type] data = deserialize(response, opts[:return_type]) else data = nil end return data, response.status, response.headers.to_h end |
#convert_to_type(data, return_type) ⇒ Mixed
Convert data to the given return type.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 227 def convert_to_type(data, return_type) return nil if data.nil? case return_type when 'String' data.to_s when 'Integer' data.to_i when 'Float' data.to_f when 'Boolean' data == true when 'Time' # parse date time (expecting ISO 8601 format) Time.parse data when 'Date' # parse date time (expecting ISO 8601 format) Date.parse data when 'Object' # generic object (usually a Hash), return directly data when /\AArray<(.+)>\z/ # e.g. Array<Pet> sub_type = $1 data.map { |item| convert_to_type(item, sub_type) } when /\AHash\<String, (.+)\>\z/ # e.g. Hash<String, Integer> sub_type = $1 {}.tap do |hash| data.each { |k, v| hash[k] = convert_to_type(v, sub_type) } end else # models (e.g. Pet) or oneOf klass = CybridApiId.const_get(return_type) klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data) end end |
#deserialize(response, return_type) ⇒ Object
Deserialize the response to the given return type.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 198 def deserialize(response, return_type) body = response.body return nil if body.nil? || body.empty? # return response body directly for String return type return body.to_s if return_type == 'String' # ensuring a default content type content_type = response.headers['Content-Type'] || 'application/json' fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type) begin data = JSON.parse("[#{body}]", :symbolize_names => true, :decimal_class => BigDecimal)[0] rescue JSON::ParserError => e if %w(String Date Time).include?(return_type) data = body else raise e end end convert_to_type data, return_type end |
#deserialize_file(response) ⇒ Object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 131 def deserialize_file(response) body = response.body if @config.return_binary_data == true # TODO: force response encoding body.to_s else content_disposition = response.headers['content-disposition'] if content_disposition && content_disposition =~ /filename=/i filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1] prefix = sanitize_filename(filename) else prefix = 'download-' end prefix = prefix + '-' unless prefix.end_with?('-') encoding = response.body.encoding tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding) response.copy_to(tempfile) tempfile.close @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\ "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\ "will be deleted automatically with GC. It's also recommended to delete the temp file "\ "explicitly with `tempfile.delete`" tempfile end end |
#json_mime?(mime) ⇒ Boolean
Check if the given MIME is a JSON MIME. JSON MIME examples:
application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*
190 191 192 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 190 def json_mime?(mime) (mime == '*/*') || !(mime =~ /^Application\/.*json(?!p)(;.*)?/i).nil? end |
#object_to_hash(obj) ⇒ String
Convert object(non-array) to hash.
342 343 344 345 346 347 348 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 342 def object_to_hash(obj) if obj.respond_to?(:to_hash) obj.to_hash else obj end end |
#object_to_http_body(model) ⇒ String
Convert object (array, hash, object, etc) to JSON string.
328 329 330 331 332 333 334 335 336 337 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 328 def object_to_http_body(model) return model if model.nil? || model.is_a?(String) local_body = nil if model.is_a?(Array) local_body = model.map { |m| object_to_hash(m) } else local_body = object_to_hash(model) end local_body.to_json end |
#sanitize_filename(filename) ⇒ String
Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif
269 270 271 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 269 def sanitize_filename(filename) filename.split(/[\/\\]/).last end |
#select_header_accept(accepts) ⇒ String
Return Accept header based on an array of accepts provided.
307 308 309 310 311 312 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 307 def select_header_accept(accepts) return nil if accepts.nil? || accepts.empty? # use JSON when present, otherwise use all of the provided json_accept = accepts.find { |s| json_mime?(s) } json_accept || accepts.join(',') end |
#select_header_content_type(content_types) ⇒ String
Return Content-Type header based on an array of content types provided.
317 318 319 320 321 322 323 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 317 def select_header_content_type(content_types) # return nil by default return if content_types.nil? || content_types.empty? # use JSON when present, otherwise use the first one json_content_type = content_types.find { |s| json_mime?(s) } json_content_type || content_types.first end |
#session ⇒ Object
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 158 def session return @session if defined?(@session) session = HTTPX.with( ssl: @config.ssl, timeout: ({ request_timeout: @config.timeout } if @config.timeout && @config.timeout.positive?), origin: "#{@config.scheme}://#{@config.host}", base_path: (@config.base_path.sub(/\/+\z/, '') if @config.base_path) ) if @config.proxy session = session.plugin(:proxy, proxy: @config.proxy) end if @config.username && @config.password session = session.plugin(:basic_auth).basic_auth(@config.username, @config.password) end session = @config.configure(session) @session = session end |
#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object
Update header and query params based on authentication settings.
284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 284 def update_params_for_auth!(header_params, query_params, auth_names) Array(auth_names).each do |auth_name| auth_setting = @config.auth_settings[auth_name] next unless auth_setting case auth_setting[:in] when 'header' then header_params[auth_setting[:key]] = auth_setting[:value] when 'query' then query_params[auth_setting[:key]] = auth_setting[:value] else fail ArgumentError, 'Authentication token must be in `query` or `header`' end end end |
#user_agent=(user_agent) ⇒ Object
Sets user agent in HTTP header
299 300 301 302 |
# File 'lib/cybrid_api_id_ruby/api_client.rb', line 299 def user_agent=(user_agent) @user_agent = user_agent @default_headers['User-Agent'] = @user_agent end |